--- title: "wallaroo.records.v1_metric_response" type: docs linkTitle: "wallaroo.records.v1_metric_response" ---
def from_str(x: Any) -> str:
def from_list(f: Callable[[Any], ~T], x: Any) -> List[~T]:
def from_int(x: Any) -> int:
def from_none(x: Any) -> Any:
def from_union(fs, x):
def to_class(c: Type[~T], x: Any) -> dict:
def to_enum(c: Type[~EnumT], x: Any) -> ~EnumT:
class MetricQuery:

The alias for this query. Used for grouping metric results together

MetricQuery(alias: str, query: str)
alias: str

The prometheus query to run

@staticmethod
def from_dict(obj: Any) -> wallaroo.records.v1_metric_response.MetricQuery:
def to_dict(self) -> dict:
class QueryType(enum.Enum):

An enumeration.

DAILY = <QueryType.DAILY: 'daily'>
INTERVAL = <QueryType.INTERVAL: 'interval'>

##### Inherited Members

enum.Enum
  name
  value

class WallarooTelemetryMetricQueryV1:
WallarooTelemetryMetricQueryV1( metrics: List[wallaroo.records.v1_metric_response.MetricQuery], query_type: wallaroo.records.v1_metric_response.QueryType, run_on_minute: Optional[int])
query_type: wallaroo.records.v1_metric_response.QueryType

Post metrics on this minute, 0 is every minute.

@staticmethod
def from_dict( obj: Any) -> wallaroo.records.v1_metric_response.WallarooTelemetryMetricQueryV1:
def to_dict(self) -> dict:
def wallaroo_telemetry_metric_query_v1_from_dict( s: Any) -> wallaroo.records.v1_metric_response.WallarooTelemetryMetricQueryV1:
def wallaroo_telemetry_metric_query_v1_to_dict( x: wallaroo.records.v1_metric_response.WallarooTelemetryMetricQueryV1) -> Any: